API
===

The great flexibility of ``ngs_toolkit`` comes from the ability to compose workflows using the API.

It provides a rich but abstract :class:`~ngs_toolkit.analysis.Analysis` object and implements various modules building on it depending on the data type.

In addition, the :mod:`~ngs_toolkit.general` module contains several analysis-independent methods and the :mod:`~ngs_toolkit.utils` module provides low-level functions of general use.

ngs_toolkit
-----------------------
.. automodule:: ngs_toolkit
    :members:

ngs_toolkit.analysis
-----------------------
.. automodule:: ngs_toolkit.analysis
    :members:

ngs_toolkit.atacseq
-----------------------
.. automodule:: ngs_toolkit.atacseq
    :members:

ngs_toolkit.chipseq
-----------------------
.. automodule:: ngs_toolkit.chipseq
    :members:

ngs_toolkit.cnv
-----------------------
.. automodule:: ngs_toolkit.cnv
    :members:

ngs_toolkit.rnaseq
-----------------------
.. automodule:: ngs_toolkit.rnaseq
    :members:

ngs_toolkit.general
-----------------------
.. automodule:: ngs_toolkit.general
    :members:

ngs_toolkit.graphics
-----------------------
.. automodule:: ngs_toolkit.graphics
    :members:

ngs_toolkit.utils
-----------------------
.. automodule:: ngs_toolkit.utils
    :members:

ngs_toolkit.parsers
-----------------------
.. automodule:: ngs_toolkit.parsers
    :members:
